<!DOCTYPE html>
<html lang="en">
{% include "shared/head" %}

  <body id="{{slug}}">
{% include "shared/navbar" %}

    <div class="container">
      <div class="row">
        <h1>{{headline}}</h1>
        {% for item in body %}
          {% if item.text %}
            {{ item.text | replace: '$JQ_VERSION', jq_version | markdownify }}
          {% endif %}

          {% if item.command %}
            {% capture resultID %}{{ "result" | unique}}{% endcapture %}
            <div class="tutorial-example">
              <div class="accordion-heading">
                <pre>{{item.command}}</pre>
                <a data-toggle="collapse" href="#{{resultID}}">Show result</a>
              </div>
              <div id="{{resultID}}" class="accordion-body collapse">
                <pre>{{item.result}}</pre>
              </div>
            </div>
          {% endif %}
        {% endfor %}
      </div>
    </div>

{% include "shared/footer" %}
  </body>
</html>
