    <div class="navbar navbar-default navbar-fixed-top" role="navigation">
      <div class="container">
        <div class="navbar-header">
          <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#nav-collapse">
            <span class="sr-only">Toggle navigation</span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
            <span class="icon-bar"></span>
          </button>
          <a class="navbar-brand" href="{{root}}/">jq</a>
        </div>

        <div class="navbar-collapse collapse" id="nav-collapse">
          <ul class="nav navbar-nav">
            {% for item in navigation %}
              <li {% if item.permalink == permalink %} class="active" {% endif %}>
                <a href="{{root}}{{item.permalink}}">{{item.name}}</a>
              </li>
            {% endfor %}
            <li><a href="https://github.com/stedolan/jq/issues">Issues</a></li>
            <li><a href="https://github.com/stedolan/jq">Source</a></li>
            <li><a href="https://jqplay.org">Try online!</a></li>
            <li><a href="https://raw.githubusercontent.com/stedolan/jq/master/NEWS">News</a></li>
          </ul>
        </div>
      </div>
    </div>
