@charset "utf-8";
body {
    padding-top: 80px;
}

.container {
    max-width: 970px;
}

/* index.liquid *******************************************/

#blurb {
    padding-top: 40px;
    p {
        font-size: 1.9em;
    }
    .btn-group {
        margin: 4px;
    }
}

#multiblurb {
    line-height: 1.7;
    text-align: center;
    font-size: 12pt;
    code {
        border: 0;
        font-size: 12pt;
    }
}

#news {
    font-size: 12pt;
    .date {
          font-style: italic;
    }
}

/* default.liquid *****************************************/

.tutorial-example {
    position: relative;
    margin-bottom: 10px;
    pre {
        margin-bottom: 0px;
    }
    a {
        position: absolute;
        top: 0px;
        right: 0px;
        padding: 15px 8px;
        color: #777777;
        font-weight: bold;
        line-height: 10px;
        font-size: 12px;
        border-left: 1px solid #DDDDDD;
        display: block;
    }
    .accordion-body pre {
        margin: 0 4px;
        border-top: 0;
        border-top-left-radius: 0;
        border-top-right-radius: 0;
    }
}

@media print {
    .tutorial-example a {
        display: none;
    }
}

/* manual.liquid ******************************************/

section {
    padding-top: 24px;
}

h3 code {
    border: 0;
    font-size: 20px;
}

@media(max-width: 991px){
    #navcolumn {
        /* Put nav column above manual content */
        position: relative !important;
        margin-bottom: 60px;
    }
}

@media(min-width: 992px) {
    #manualcontent {
        /* Put nav column left of manual content */
        padding-left: 280px;
    }
}

.nav-pills {
    li a {
        padding: 8px 12px;
    }
    margin-bottom: 20px;
}

.manual-example table {
    border-top: 1px solid #E5E5E5;
    td {
        white-space: pre-wrap;
        font-family: Monaco, Menlo, Consolas, "Courier New", monospace;
    }
    td.jqprogram {
        font-weight: bold;
    }
    th {
        text-align: right;
        padding-right: 10px;
    }
}

@media print {
    #navcolumn {
        display: none !important;
    }
    .manual-example {
        display: block !important;
        height: auto !important;
    }
    .jqplay-btn {
        display: none !important;
    }
}

/* shared/_footer.liquid **********************************/

footer {
    background-color: #F5F5F5;
    padding: 20px 0;
    margin-top: 40px;
    color: #999999;
    text-align: center;
    p {
        margin: 8px 0;
    }
}

/* typeahead **********************************************/

.twitter-typeahead {
    width: 100%;
}

.tt-menu {
    width: 100%;
    background-color: #fff;
    padding: 8px 0;
    border: 1px solid #ccc;
    border: 1px solid rgba(0, 0, 0, 0.2);
    -webkit-border-radius: 8px;
       -moz-border-radius: 8px;
            border-radius: 8px;
    -webkit-box-shadow: 0 5px 10px rgba(0,0,0,.2);
       -moz-box-shadow: 0 5px 10px rgba(0,0,0,.2);
            box-shadow: 0 5px 10px rgba(0,0,0,.2);
}

.tt-suggestion {
    padding: 3px 20px;
    &:hover {
        cursor: pointer;
        color: #fff;
        background-color: #446e9b;
    }
    &.tt-cursor {
        color: #fff;
        background-color: #446e9b;
    }
    p {
        margin: 0;
    }
}
