<!DOCTYPE html>
<html lang="en">
{% include "shared/head" %}

  <body id="{{slug}}">
{% include "shared/navbar" %}

    <div class="container">
      <div class="row">
        <div class="jumbotron">
          <div class="row">
            <div class="col-sm-6">
              <img src="{{root}}/jq.png" class="img-responsive" alt="jq logo"
                  width="400" height="220">
            </div>
            <div class="col-sm-6">
              <div id="blurb">
                {{blurb | markdownify}}

                <div class="btn-toolbar" role="toolbar">
                  <div class="btn-group" role="group">
                    <a class="btn btn-primary dropdown-toggle" data-toggle="dropdown" href="#">
                      Download jq 1.5
                      <span class="caret"></span>
                    </a>
                    <ul class="dropdown-menu">
                      <li><a href="https://github.com/stedolan/jq/releases/download/jq-1.5/jq-linux64">Linux (64-bit)</a></li>
                      <li><a href="https://github.com/stedolan/jq/releases/download/jq-1.5/jq-osx-amd64">OS X (64-bit)</a></li>
                      <li><a href="https://github.com/stedolan/jq/releases/download/jq-1.5/jq-win64.exe">Windows (64-bit)</a></li>
                      <li><a href="/jq/download/">Other platforms, older versions, and source</a></li>
                    </ul>
                  </div>

                  <div class="btn-group">
                    <a class="btn btn-primary" href="https://jqplay.org">
                      Try online at jqplay.org!
                    </a>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>

      <div class="row" id="multiblurb">
        <div class="col-sm-4">{{body1 | markdownify}}</div>
        <div class="col-sm-4">{{body2 | markdownify}}</div>
        <div class="col-sm-4">{{body3 | markdownify}}</div>
      </div>

      <div class="row" style="text-align:center; margin-top: 30px">
        {{tail | markdownify}}
      </div>

      <div class="row">
        <h2>News</h2>
        <div id="news">
          <ul>
            {% for item in news %}
              <li>
                <span class="date">{{item.date}}</span>
                {{item.body | markdownify}}
              </li>
            {% endfor %}
          </ul>
        </div>
      </div>
    </div>

{% include "shared/footer" %}
  </body>
</html>
